local base = {}
-- ------------------------------------------------------------
local pairs        = pairs
local unpack       = unpack
local rawget       = rawget
local setmetatable = setmetatable
local getmetatable = getmetatable

function base.rawnew(class, object)
	return setmetatable(object or {}, class)
end

function base.new(class, ...)
	if class.__init
		then return class:__init(...)
		else return base.rawnew(class, ...)
	end
end

function base.initclass(class)
	if class == nil then class = {} end
	if class.__index == nil then class.__index = class end
	return class
end

local MetaClass = { __call = new }
function base.class(class)
	return setmetatable(base.initclass(class), MetaClass)
end

base.classof = getmetatable

function base.isclass(class)
	return base.classof(class) == MetaClass
end

function base.instanceof(object, class)
	return base.classof(object) == class
end

base.memberof = rawget

base.members = pairs

-- ------------------------------------------------------------
return base