-- -------------------------------------------------------------
--   .
-- -  .lua   .
--        
--
-- note + dofile("lua/test.lua")
-- note + _(_)
-- script execute
--
-- dofile        ,       .
-- -------------------------------------------------------------
--    /  obj   .
-- -------------------------------------------------------------
function dump(obj)
	if not obj then
		World.echo("param is nil")
		return
	end
	
	local meta = getmetatable(obj)
	if not meta then
		World.echo("No metatable found")
		return
	end
	
	for k,v in ipairs(meta) do
		World.echo("Metatable has key '"..k.."'")
	end
end


function enum_example(room_vnum)
	local room = World.find_room(room_vnum)
	if room == nil then
		World.echo("Room not found")
		return
	end
	
	World.echo("{GPeoples:{x")
	for ch in enum_people(room) do
		World.echo(ch.name)
	end
	
	World.echo("{MObjects:{x")
	for obj in enum_room_contents(room) do
		ostat(obj.vnum)
		World.echo("{Y-----------{x");
	end
end

function ostat(vnum)
	local o = World.get_obj_world(vnum)
	if o == nil then
		World.echo("Object not found")
		return
	end	

	World.echo("Name: "..o.name)
	World.echo("Descr: "..o.descr)
	World.echo("Short descr: "..o.short_descr)
	World.echo("Long descr: "..o.long_descr)
	
	local ch = o.carried_by
	if ch then
		World.echo("Carried by: "..ch.name.." at "..ch.room.name)
	else
		World.echo("Carried by: none")
	end
end	

function test_act()
	local ch = World.find_mobile("papa")
	local obj = World.get_obj(100)
	ch.act("all", obj, obj, " $cr  {Y$or{x,   $P.")
end
-- -------------------------------------------------------------
--                 sector.
-- -------------------------------------------------------------
test_vnum_table = {}
function get_areas_with_sector(sector)
    local area, mansion, room = World.get_area(), World.get_mansion()
    local itogo, count = 0
    repeat
        if area.sun ~= 4 and area ~= mansion and not (area.has_flag("no_quests") or area.has_flag("godsonly") or area.has_flag("hidden")) then
            count = 0 
            room = area.rooms
            while room do
                if room.sector == sector then
                    table.insert(test_vnum_table, room)
                    count = count + 1
                end
                room = room.next
            end
            if count > 0 then
                World.echo(area.name.."|  "..area.sun.."| -  "..count)
                itogo = itogo + count
            end
        end
        area = area.next
    until not area
    World.echo(" "..itogo)
end
-- -------------------------------------------------------------
--       "[key]" = "value" (debug).
-- -------------------------------------------------------------
function global_debug_table(show_table)
    Mud.log(":  ")
    local i, v
    for i, v in pairs(show_table) do
        Mud.log("["..i.."] = "..v)
    end
end
-- -------------------------------------------------------------
--   interpret (   c++)  
-- -------------------------------------------------------------
function global_one_time_test(command)
    local os_clock, ch, i, start_time = os.clock, World.get_char("imp")
    start_time = os_clock()
    for i = 1, 500 do -- 
        ch.execute(command)
    end
    return os_clock() - start_time
end

function global_time_tests()
    World.echo("north ("     ..global_one_time_test("north")     ..") ms") --     
    World.echo("autoassist ("..global_one_time_test("autoassist")..") ms") --       
    World.echo("clanskill (" ..global_one_time_test("clanskill") ..") ms") --    (4  )   
    World.echo("gack ("      ..global_one_time_test("gack")      ..") ms") --     
    World.echo("tackle ("    ..global_one_time_test("tackle")    ..") ms") --       
    World.echo("facepalm ("  ..global_one_time_test("facepalm")  ..") ms") --    (4  )   
end

function global_time_test_double_variants()
    local time1 = global_one_time_test("north")
    local time2 = global_one_time_test("north") --  2  -      

    local delta = string.format('%.6f', time1 - time2)
    local percent = string.format('%.6f', ((time1 - time2) / time1) * 100)

    World.echo("time 1 ("..time1..") ms, time 2 ("..time2..") ms, delta ("..delta..") ms, percent ("..percent..") ms")
end

World.echo("lua/test.lua loaded success.")
